/*
 * Copyright (c) 2009 Mysema Ltd.
 * All rights reserved.
 * 
 */
package com.mysema.commons.jetty;

import java.util.HashMap;
import java.util.Map;

import org.mortbay.jetty.Connector;
import org.mortbay.jetty.Handler;
import org.mortbay.jetty.Server;
import org.mortbay.jetty.handler.DefaultHandler;
import org.mortbay.jetty.nio.SelectChannelConnector;
import org.mortbay.jetty.security.SslSocketConnector;
import org.mortbay.jetty.webapp.WebAppContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * JettyHelper provides
 *
 * @author Timo Westkamper
 * @version $Id$
 */
public class JettyHelper {
    
    private static final Logger logger = LoggerFactory.getLogger(JettyHelper.class);
    
    private static final Map<Integer,Server> servers = new HashMap<Integer,Server>();
    
    public static boolean runningAt(int port){
        return servers.containsKey(port);
    }
    
    public static void startJetty(String warPath, String contextPath, int port, int securePort) throws Exception{
        if (servers.containsKey(port)){
            logger.error("Already one Jetty instance running on port " + port, new RuntimeException());
            return;
        }
        final Server server = new Server();
        servers.put(port, server);
        
        // http
        SelectChannelConnector httpConnector = new SelectChannelConnector();
        httpConnector.setPort(port);
        httpConnector.setConfidentialPort(securePort);
               
        // https
        SslSocketConnector httpsConnector = new SslSocketConnector();
        httpsConnector.setPort(securePort);
        httpsConnector.setMaxIdleTime(60000);
        httpsConnector.setKeystore("etc/demokeystore");
        httpsConnector.setPassword("OBF:1vny1zlo1x8e1vnw1vn61x8g1zlu1vn4");
        httpsConnector.setKeyPassword("OBF:1u2u1wml1z7s1z7a1wnl1u2g");
        
        server.setConnectors(new Connector[]{httpConnector, httpsConnector});
        
        WebAppContext webappcontext = new WebAppContext();
        webappcontext.setContextPath(contextPath);
        webappcontext.setWar(warPath);      
        server.setHandlers(new Handler[]{webappcontext, new DefaultHandler()});
        
        server.start();
        logger.info("Jetty running on port " + port); 
    }    
       
    public static void stopJettyAtPort(int port) throws Exception{
        Server server = servers.get(port);
        if (server != null){
            server.stop();
            logger.info("Stopped Jetty on port " + port);
        }else{
            logger.warn("No Jetty instance running on port " + port, new RuntimeException());
        }
    }
}
